#
# spec file for package ktop
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ktop
Version:        0.4.1
Release:        1.1
Summary:        A top-like tool for your Kubernetes clusters
License:        Apache-2.0
URL:            https://github.com/vladimirvivien/ktop
Source:         ktop-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
A top-like tool for your Kubernetes cluster.

Following the tradition of Unix/Linux top tools, ktop is a tool that displays useful metrics information about nodes, pods, and other workload resources running in a Kubernetes cluster.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Jul  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.4.1:
  * Fix Homebrew cask release (#56)
* Mon Jul  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.4.0:
  * This release introduces new command-line options to filter
    which columns are displayed in nodes and pods tables.
    Users can now customize the view by specifying columns with
  - -node-columns and --pod-columns flags.
  - Column Filtering
    You can now customize which columns are displayed in the
    nodes and pods tables. This is useful when you want to focus
    on specific metrics or when working with limited screen
    space.
    To show only specific node columns:
    ktop --node-columns NAME,CPU,MEM
    To show only specific pod columns:
    ktop --pod-columns NAMESPACE,POD,CPU,MEMORY
    You can combine both filters:
    ktop --node-columns NAME,CPU,MEM --pod-columns NAMESPACE,POD,STATUS
    Available node columns:
  - NAME
  - STATUS
  - AGE
  - VERSION
  - INT/EXT IPs
  - OS/ARC
  - PODS/IMGs
  - DISK
  - CPU
  - MEM
    Available pod columns:
  - NAMESPACE
  - POD
  - READY
  - STATUS
  - RESTARTS
  - AGE
  - VOLS
  - IP
  - NODE
  - CPU
  - MEMORY
    These enhancements improve the usability and customization of
    ktop, allowing users to tailor the displayed information to
    their needs. The updated automation scripts also ensure a
    smoother release workflow.
  * What's Changed
  - Update CI/release scripts (#55)
  - Add column filtering options for nodes and pods in ktop (#51)
  - Bump golang.org/x/net from 0.36.0 to 0.38.0
  - Bump golang.org/x/net from 0.23.0 to 0.36.0
* Fri Jul 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.3.7:
  * Fixes/updates to goreleaser and github actions
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.3.6:
  * Bump golang.org/x/net from 0.17.0 to 0.23.0
  * Bump google.golang.org/protobuf from 1.27.1 to 1.33.0
  * Bump golang.org/x/net from 0.7.0 to 0.17.0
  * Bump gopkg.in/yaml.v3 from 3.0.0-20210107192922-496545a6307b to
    3.0.0
* Mon Apr 17 2023 kastl@b1-systems.de
- Update to version 0.3.5:
  * Implements an informer for metrics-api types
  * Support for OCI image release
  * Bump golang.org/x/crypto from 0.0.0-20220214200702-86341886e292
    to 0.1.0
  * Bump golang.org/x/net from 0.0.0-20220127200216-cd36cc0744dd to
    0.7.0
  * Bump golang.org/x/text from 0.3.7 to 0.3.8
  * Bump github.com/emicklei/go-restful
  * Homebrew documentation update
- skip non-existent releases
  * 0.3.1
  * 0.3.2
  * 0.3.3
  * 0.3.4
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.3.0:
  * GitHub Action and release automation
  * test user yaml
  * Fixes for authorization detection; client-go updates; UI updates
  * Refactor code to use typed clients and informers
  * GUI updates and doc adjustments
  * chore: Rename Nmspaces to Namespaces
* Tue Jan 11 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.17 or higher
* Sat Jan  1 2022 kastl@b1-systems.de
- Update to version 0.2.0:
  * Support for kubectl/krew plugin
  * small fix to support clusters with oidc auth
  * Documentation update
  * Refinement of the UI
  * Another code refactor
  * Remove controller-runtime to use simple watchers
  * Refreshing node panel with new columns
  * Simplify controller-runtime usage to only retrieve obj list
  * Remodling with controller-runtime
  * Node and pod overview screen works
* Sat Jan  1 2022 Johannes Kastl <kastl@b1-systems.de>
- creating package at version 0.2.0
